/**
 * @license
 * Copyright Google LLC All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */

/**
 * @fileoverview
 * While Angular only uses Trusted Types internally for the time being,
 * references to Trusted Types could leak into our core.d.ts, which would force
 * anyone compiling against @angular/core to provide the @types/trusted-types
 * package in their compilation unit.
 *
 * Until https://github.com/microsoft/TypeScript/issues/30024 is resolved, we
 * will keep Angular's public API surface free of references to Trusted Types.
 * For internal and semi-private APIs that need to reference Trusted Types, the
 * minimal type definitions for the Trusted Types API provided by this module
 * should be used instead.
 *
 * Adapted from
 * https://github.com/DefinitelyTyped/DefinitelyTyped/blob/master/types/trusted-types/index.d.ts
 * but restricted to the API surface used within Angular.
 */

export type TrustedHTML = {
  __brand__: 'TrustedHTML'
};
export type TrustedScript = {
  __brand__: 'TrustedScript'
};
export type TrustedScriptURL = {
  __brand__: 'TrustedScriptURL'
};

export interface TrustedTypePolicyFactory {
  createPolicy(policyName: string, policyOptions: {
    createHTML?: (input: string) => string,
    createScript?: (input: string) => string,
    createScriptURL?: (input: string) => string,
  }): TrustedTypePolicy;
  getAttributeType(tagName: string, attribute: string): string|null;
}

export interface TrustedTypePolicy {
  createHTML(input: string): TrustedHTML;
  createScript(input: string): TrustedScript;
  createScriptURL(input: string): TrustedScriptURL;
}
